@@ -1,9 +1,43 @@
+import datetime
+import pathlib
+import time
+
+import ckan.logic as logic
 import ckan.model as model
 import click
 
+from . import app_res
 from .depotize import depotize
 from .figshare import figshare
 from .internal import internal, internal_upgrade
+from . import jobs
+
+
+def click_echo(message, am_on_a_new_line):
+    if not am_on_a_new_line:
+        click.echo("")
+    click.echo(message)
+
+
+@click.command()
+@click.argument('path')
+@click.argument('dataset_id')
+@click.option('--delete-source', is_flag=True,
+              help='Delete the original local file')
+def append_resource(path, dataset_id, delete_source=False):
+    """Append a resource to a dataset
+
+    This can be done even after the dataset is made active.
+    It can be used to e.g. append post-processed RT-DC data to an
+    existing dataset.
+
+    Pass the path `path` to a resource, and it will be added to the
+    specified `dataset_id` (id or name).
+    """
+    path = pathlib.Path(path)
+    app_res.append_resource(path=path,
+                            dataset_id=dataset_id,
+                            copy=not delete_source)
 
 
 @click.command()
@@ -79,6 +113,60 @@ def import_internal(limit, start_date="2000-01-01", end_date="3000-01-01"):
     internal(limit=limit, start_date=start_date, end_date=end_date)
 
 
+@click.command()
+def list_all_resources():
+    """List all (public and private) resource ids"""
+    datasets = model.Session.query(model.Package)
+    for dataset in datasets:
+        for resource in dataset.resources:
+            click.echo(resource.id)
+
+
+@click.option('--modified-days', default=-1,
+              help='Only run for datasets modified within this number of days '
+                   + 'in the past. Set to -1 to apply to all datasets.')
+@click.command()
+def run_jobs_dcor_depot(modified_days=-1):
+    """Compute condensed resource all .rtdc files
+
+    This also happens for draft datasets.
+    """
+    # go through all datasets
+    datasets = model.Session.query(model.Package)
+
+    if modified_days >= 0:
+        # Search only the last `days` days.
+        past = datetime.date.today() - datetime.timedelta(days=modified_days)
+        past_str = time.strftime("%Y-%m-%d", past.timetuple())
+        datasets = datasets.filter(model.Package.metadata_modified >= past_str)
+
+    nl = False  # new line character
+    for dataset in datasets:
+        nl = False
+        click.echo(f"Checking dataset {dataset.id}\r", nl=False)
+        usr_id = dataset.creator_user_id
+        ds_dict = dataset.as_dict()
+        ds_dict["organization"] = logic.get_action("organization_show")(
+                {'ignore_auth': True}, {"id": dataset.owner_org})
+        for resource in dataset.resources:
+            res_dict = resource.as_dict()
+            try:
+                if jobs.symlink_user_dataset(pkg=ds_dict,
+                                             usr={"name": usr_id},
+                                             resource=res_dict):
+                    click_echo(f"Created symlink for {resource.name}", nl)
+                    nl = True
+            except KeyboardInterrupt:
+                raise
+            except BaseException as e:
+                click_echo(
+                    f"{e.__class__.__name__}: {e} for {resource.name}", nl)
+                nl = True
+    if not nl:
+        click.echo("")
+    click.echo("Done!")
+
+
 @click.command()
 @click.option('--start-date', default="2000-01-01",
               help='Search for upgraded resources in the depot starting '
@@ -101,18 +189,12 @@ def upgrade_internal(start_date="2000-01-01", end_date="3000-01-01"):
     internal_upgrade(start_date=start_date, end_date=end_date)
 
 
-@click.command()
-def list_all_resources():
-    """List all (public and private) resource ids"""
-    datasets = model.Session.query(model.Package)
-    for dataset in datasets:
-        for resource in dataset.resources:
-            click.echo(resource.id)
-
-
 def get_commands():
-    return [depotize_archive,
+    return [append_resource,
+            depotize_archive,
             import_figshare,
             import_internal,
+            list_all_resources,
+            run_jobs_dcor_depot,
             upgrade_internal,
-            list_all_resources]
+            ]
